Improve this Doc View Source

Configures the mock implementation of `$exceptionHandler` to rethrow or to log errors passed to the `$exceptionHandler`.

## Methods

- ###

  `mode(mode);`

  Sets the logging mode.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  mode | string | Mode of operation, defaults to `rethrow`. `log`: Sometimes it is desirable to test that an error is thrown, for this case the `log` mode stores an array of errors in `$exceptionHandler.errors`, to allow later assertion of them. See assertEmpty() and reset(). `rethrow`: If any errors are passed to the handler in tests, it typically means that there is a bug in the application or test, so this mock will make these tests fail. For any implementations that expect exceptions to be thrown, the `rethrow` mode will also maintain a log of thrown errors in `$exceptionHandler.errors`.